---
id: BFLLM
---

# Bluefly LLM Integration (BFLLM)

## Important URLs

### Development URLs
- **Local Development Server:** `http://localhost:3003`
  - Start with `npm run dev`
  - Check `.env` file for actual port configuration
- **API Documentation:** `http://localhost:3003/api-docs`
  - Swagger/OpenAPI documentation when server is running
- **Health Check:** `http://localhost:3003/health`
  - Endpoint to verify LLM service status
- **Model Dashboard:** `http://localhost:3003/dashboard`
  - Real-time model performance and usage metrics

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFLLM`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFLLM/-/pipelines`
- **Package Registry:** `https://gitlab.com/bluefly-llm/BFLLM/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/BFLLM/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **API Reference:** Available at `/docs` endpoint when server is running
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - Model integration guides
  - API specifications
  - Development guides

### Related Services
- **BFAPI Integration:** `http://localhost:3001` (Main API)
- **BFMCP Integration:** `http://localhost:3002` (Model Control Plane)
- **BFUI Connection:** `http://localhost:3000` (Frontend that consumes LLM services)
- **Model Monitoring:** `http://localhost:9090` (if Prometheus is configured)

### Model Endpoints
- **Inference API:** `http://localhost:3003/v1/models/{model_id}/infer`
- **Fine-tuning API:** `http://localhost:3003/v1/models/{model_id}/finetune`
- **Model Management:** `http://localhost:3003/v1/models/manage`
- **Model Registry:** `http://localhost:3003/v1/models/registry`
- **Batch Processing:** `http://localhost:3003/v1/batch`

### Environment-Specific URLs
- **Development:** `https://dev-llm.bluefly.ai`
- **Staging:** `https://staging-llm.bluefly.ai`
- **Production:** `https://llm.bluefly.ai`

### Model-Specific URLs
- **Model Registry UI:** `http://localhost:3003/registry`
- **Model Metrics:** `http://localhost:3003/metrics`
- **Model Logs:** `http://localhost:3003/logs`
- **Training Dashboard:** `http://localhost:3003/training`

## Quick Start
```bash
# Clone repository
git clone https://gitlab.com/bluefly-llm/BFLLM.git

# Install dependencies
npm install

# Set up environment
cp .env.example .env

# Start development server
npm run dev
```

For detailed setup instructions, see [Setup Guide](./setup).

## Model Integration
For information on integrating new models, see [Model Integration Guide](./model-integration).
