---
id: BFMCP-mcp-servers
---
# MCP Servers

The Bluefly Model Context Protocol (MCP) implements servers that integrate with various external services and APIs. These servers extend the capabilities of LLMs by providing access to tools and resources that would otherwise be unavailable.

## Available MCP Servers

| Server Name | Description | Status |
|-------------|-------------|--------|
| [GitLab/Kubernetes](./gitlab-k8s/README) | Provides integration with GitLab repositories and Kubernetes clusters | Production |
| [Google Drive](https://github.com/modelcontextprotocol/servers/tree/main/src/gdrive) | Integrates with Google Drive for file access, search, and more | Production |

## Installation

MCP servers are configured in the MCP settings file:

- For Cline CLI: `~/Library/Application Support/Cursor/User/globalStorage/saoudrizwan.claude-dev/settings/cline_mcp_settings.json`
- For Claude Desktop: `~/Library/Application Support/Claude/claude_desktop_config.json`

Each server requires specific configuration parameters to function properly. See the respective server documentation for details.

## Common Configuration Format

```json
{
  "mcpServers": {
    "server-name": {
      "command": "node",
      "args": ["path/to/server/index.js"],
      "disabled": false,
      "autoApprove": [],
      "env": {
        "API_KEY": "your-api-key",
        "OTHER_ENV_VAR": "value"
      }
    }
  }
}
```

## Multi-Environment Support

MCP servers are designed to work across different environments:

### Local Development

Servers can be run locally during development with environment variables configured in the MCP settings file.

### GitLab CI/CD

For CI/CD environments, servers can be configured using GitLab CI variables and run as part of the pipeline.

### AWS Kubernetes

In production environments, servers can be deployed as containers in Kubernetes with proper ConfigMap and Secret resources for configuration.

## Creating Custom MCP Servers

To create a custom MCP server, refer to the [MCP SDK Documentation](https://github.com/modelcontextprotocol/sdk) and the [Server Development Guide](../../BFMCP/development/server-development).

## Testing MCP Servers

Each MCP server includes a test script that allows for basic functionality testing without requiring a full MCP client. See the individual server documentation for details on testing.
