---
title: BFCLI
description: Documentation for BFCLI
id: components-bfcli
---

# Bluefly Command Line Interface (BFCLI)

## Important URLs

### Repository & CI/CD
- **Repository:** `https://gitlab.com/bluefly-llm/BFCLI`
  - Main development branch: `main`
  - Release branch: `release`
- **CI/CD Pipeline:** `https://gitlab.com/bluefly-llm/BFCLI/-/pipelines`
- **Package Registry:** 
  - NPM Package: `@bluefly/cli`
  - GitLab Registry: `https://gitlab.com/bluefly-llm/BFCLI/container_registry`

### Documentation
- **Project Documentation (Local):** `http://localhost:8080/docs/components/bfcli/`
  - Requires BFDOCS to be running (`cd ../BFDOCS && npm run docs:serve`)
- **CLI Documentation:**
  - Run `bfcli --help` for command list
  - Run `bfcli <command> --help` for specific command help
- **Technical Documentation:** Located in `/docs` folder in repository
  - Architecture diagrams
  - Command reference
  - Plugin development guide
  - Development setup guide

### Related Services
- **BFAPI Integration:** `http://localhost:3001` (Backend API)
- **BFMCP Integration:** `http://localhost:3002` (Model Control Plane)
- **Monitoring Dashboard:** `http://localhost:9090` (if configured)

### Development Tools
- **Test Runner:** Run with `npm test`
- **Coverage Report:** Generate with `npm run test:coverage`
- **Documentation Generation:** `npm run docs:generate`
- **TypeScript Compilation:** `npm run build`

### Package URLs
- **NPM Registry:** `https://www.npmjs.com/package/@bluefly/cli`
- **GitHub Mirror:** `https://github.com/bluefly-llm/bfcli`
- **Documentation Site:** `https://docs.bluefly.ai/cli`

## Quick Start
```bash
# Install globally
npm install -g @bluefly/cli

# Or clone repository for development
git clone https://gitlab.com/bluefly-llm/BFCLI.git
cd BFCLI
npm install

# Set up environment
cp .env.example .env

# Build the CLI
npm run build

# Link for local development
npm link

# Run CLI
bfcli --help
```

For detailed setup instructions, see [Setup Guide](setup).

## Command Development
For information on creating new commands, see [Command Development Guide](command-development).

## Overview

BFCLI is a command-line interface that provides access to all features of the
Bluefly LLM ecosystem. It enables developers and users to interact with models,
analyze documents, generate RFP responses, and manage development workflows
through a unified CLI.

## Documentation Sections

- [API Reference](./api/index) - Public API for programmatic usage
- [Technical Documentation](./technical/index) - Implementation details and
  architecture
- [User Guide](./user/index) - Usage instructions and examples

## Quick Navigation

| Section                                       | Description              |
| --------------------------------------------- | ------------------------ |
| [Installation](../README.md#installation)     | How to install BFCLI     |
| [Usage](../README.md#usage)                   | Basic usage instructions |
| [Command Groups](../README.md#command-groups) | Available command groups |
| [Development](../README.md#development)       | Development guidelines   |

## Contributing to Documentation

All documentation for BFCLI is maintained in the BFCLI repository and
synchronized with the central documentation hub. To contribute to this
documentation:

1. Make changes directly to the markdown files in the `docs/` directory
2. Submit a merge request with your changes
3. After approval, changes will be synchronized to the central documentation hub

For documentation guidelines, see the
[Documentation Workflow Guide](https://gitlab.bluefly.io/blueflyio/internal-projects/llm/bfdocs/blob/main/docs/guides/documentation-workflow)
in the BFDOCS repository.

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Getting Started

For installation and setup instructions, see the [Getting Started Guide](../getting-started/installation).

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
