---
title: BFLLM
description: Documentation for BFLLM
id: components-bfllm
---

# BFLLM Documentation

Welcome to the Bluefly LLM Services documentation.

## Overview

BFLLM is a comprehensive platform for working with large language models, providing services for model inference, training, learning, and integration with third-party AI services.

## Key Features

- **Model Abstraction** - Unified interface for multiple LLM providers
- **Learning System** - Tools for continuous improvement of models
- **Model Registry** - Integration with GitLab ML Model Registry
- **Claude Integration** - First-class support for Anthropic's Claude models
- **Training Tools** - Capabilities for fine-tuning and model adaptation

## Documentation Sections

### Machine Learning

- [Inference Services](./ml/inference-services) - How to use LLMs for inference
- [Learning System](./ml/learning-system) - Using the continuous learning capabilities

### API Reference

- [API Documentation](./api/API) - Full API reference

### Technical Documentation

- [CI/CD Troubleshooting](./technical/CI-TROUBLESHOOTING) - Solving CI/CD issues

## Getting Started

To get started with BFLLM, install the package:

```bash
npm install @bluefly/bfllm
```

Then configure it in your application:

```javascript
import { modelService } from '@bluefly/bfllm';

// Initialize with configuration
modelService.init({
  defaultModel: 'claude-3-sonnet-20240229',
  apiKey: process.env.CLAUDE_API_KEY,
});

// Use the service
const response = await modelService.generate({
  prompt: 'Explain quantum computing in simple terms',
  maxTokens: 500,
});

console.log(response.text);
```

## Quick Links

- [API Reference](./api/README)
- [Technical Documentation](./technical/README)
- [User Guide](./user-guide/README)

## Development

For development guidelines and contribution information, see the [Development Guide](../development/setup).
