---
id: getting-started-README
---
# Getting Started with Bluefly Platform

<!-- title: Getting Started with Bluefly Platform -->
<!-- description: Learn how to get started with the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

This guide will help you get started with the Bluefly Platform. We'll cover the basic concepts, installation, and your first steps with the platform.

## What is Bluefly Platform?

The Bluefly Platform is a comprehensive solution for building and deploying AI-powered applications. It consists of several key components:

- **BFCLI**: A command-line interface for managing the platform
- **BFAPI**: REST API services for integration
- **BFAgent**: An AI agent framework for automation
- **Drupal Integration**: Modules and recipes for Drupal integration

## Prerequisites

Before you begin, ensure you have:

- Node.js 18 or later
- Git
- Docker (for containerized deployments)
- Access to GitLab repository
- Required API keys and credentials

## Quick Start

1. Install BFCLI:
   ```bash
   npm install -g @bluefly/cli
   ```

2. Initialize a new project:
   ```bash
   bfcli init my-project
   cd my-project
   ```

3. Start the development environment:
   ```bash
   bfcli dev
   ```

4. Access the platform at `http://localhost:3000`

## Next Steps

- [Installation Guide](./installation): Detailed installation instructions
- [Quick Start Guide](./quickstart): Step-by-step tutorial
- [Architecture Overview](./architecture): Platform architecture and components

## Platform Components

### BFCLI

The command-line interface provides tools for:
- Project management
- Development workflow
- Deployment
- Monitoring

### BFAPI

REST API services enable:
- Integration with external systems
- Authentication and authorization
- Data management
- AI model access

### BFAgent

The AI agent framework supports:
- Task automation
- Workflow orchestration
- Natural language processing
- Decision making

### Drupal Integration

Drupal modules and recipes provide:
- Content management
- User authentication
- API integration
- Custom workflows

## Development Workflow

1. **Setup**
   - Install required tools
   - Configure environment
   - Clone repositories

2. **Development**
   - Create feature branches
   - Implement changes
   - Run tests
   - Submit merge requests

3. **Deployment**
   - Review changes
   - Run CI/CD pipeline
   - Deploy to environment
   - Monitor performance

## Support and Resources

- [Documentation](../README): Complete platform documentation
- [GitLab Issues](https://gitlab.com/blueflyio/internal-projects/llm/-/issues): Report bugs and request features
- [CI/CD Pipeline](https://gitlab.com/blueflyio/internal-projects/llm/-/pipelines): View build status
- [Wiki](https://gitlab.com/blueflyio/internal-projects/llm/-/wikis): Additional resources

## Related Documentation

- [Development Standards](../development/standards)
- [API Reference](../reference/api)
- [CLI Reference](../reference/cli)
- [Architecture Overview](../reference/architecture) 
