---
id: modules-development-native_ai-DRUPAL_ORG_PAGE
---
# Drupal Native AI

## Overview

Drupal Native AI is a vendor-agnostic AI integration module for Drupal with support for both open-source and commercial AI models. The module provides a unified interface for integrating AI capabilities into Drupal sites with a focus on flexibility, extensibility, and standards compliance.

## Features

- **Provider-agnostic API**: Standardized interface for interacting with multiple AI providers
- **Model management**: Register, configure, and benchmark AI models
- **Field integration**: Process and augment field data using AI capabilities
- **Content analysis**: Analyze and enhance Drupal content using AI
- **Content generation**: Generate content using AI models
- **Entity processing**: Process entities using AI capabilities
- **Migration tools**: AI-powered content migration utilities
- **Streaming support**: Support for streaming AI responses
- **State management**: Track and manage AI operations state
- **Metrics collection**: Collect and analyze AI usage metrics

## Module Architecture

The module follows a provider-based architecture with these key components:

1. **AI Service**: Central service for interacting with AI providers
2. **Provider System**: Pluggable system for integrating with different AI providers
3. **Model Registry**: Service for registering and managing AI models
4. **Field Processor**: Service for processing field data with AI
5. **Entity Processor**: Service for processing entity data with AI
6. **Content Generator**: Service for generating content with AI
7. **Streaming Service**: Service for streaming AI responses
8. **Metrics Collector**: Service for collecting and analyzing AI usage metrics

## Use Cases

### Content Enhancement

- Automatically improve content quality
- Generate summaries for long-form content
- Extract keywords and topics from content
- Suggest related content based on AI analysis

### Field Processing

- Automatically process field data during entity save
- Validate field content against guidelines
- Generate field data based on other fields
- Enhance existing field data with AI processing

### Content Generation

- Generate draft content for editors
- Create summaries from long-form content
- Generate metadata from content (tags, categories)
- Create image descriptions for accessibility

### Migration Assistance

- Enhance migration mappings with AI processing
- Validate migrated content against guidelines
- Generate missing content during migration
- Transform content formats during migration

## Requirements

- PHP 8.1 or higher
- Drupal 10.1 or 11.0
- Required Drupal core modules (see module page for details)

## Similar Modules

- **OpenAI Integration**: Focused specifically on OpenAI integration
- **AI Content Generator**: Focused on content generation
- **LLM API**: Generic LLM API integration

## Credits

This module was created by the Drupal community with contributions from various individuals and organizations. See the MAINTAINERS.txt file for details.
