---
id: modules-development-native_ai-FEATURE_COMPARISON
---
# Feature Comparison Dashboard

The Feature Comparison Dashboard provides a comprehensive, interactive visualization to compare AI model features, capabilities, performance metrics, and cost factors across different providers.

## Overview

This dashboard allows you to:

- Compare features and capabilities across multiple models
- Filter models by provider type (commercial vs. native)
- Filter features by importance level
- Search for specific features
- Highlight differences between models
- Show only features with differences
- Export comparison data to CSV or JSON formats

## Usage

### Accessing the Dashboard

Navigate to **Admin > Configuration > AI > Drupal Native AI > AI Model Dashboard > Feature Comparison**

### Dashboard Controls

The dashboard provides several controls to customize your comparison:

#### Filters

- **Provider Type Filter**: Filter models by type (All, Commercial, Native)
- **Importance Filter**: Filter features by importance level (All, Critical, Important, Optional)
- **Search Box**: Filter features by name or description

#### Visualization Controls

- **Highlight Differences**: Visually highlight cells where models have different values
- **Show Only Differences**: Hide features where all models have the same value
- **Export**: Export the comparison data in CSV or JSON format

### Model Selection

The sidebar allows you to select which models to include in the comparison. Simply check or uncheck the models you want to compare.

### Feature Categories

Features are organized into categories:

- **Core Features**: Basic capabilities like text generation, code generation, etc.
- **Model Capabilities**: Technical specifications like context window size
- **Performance Metrics**: Speed, latency, and throughput measurements
- **Cost Factors**: Pricing details and resource requirements
- **Security Features**: Security-related capabilities
- **Compliance Factors**: Regulatory compliance features

Each category can be expanded or collapsed to focus on specific areas of interest.

## Value Analysis

The dashboard automatically analyzes numeric values to identify better/worse/average:

- **Green**: Better values (higher for metrics where higher is better, lower for metrics where lower is better)
- **Yellow**: Average values
- **Red**: Worse values
- **Blue Outline**: Differences detected between models

## Adding Custom Features

You can add custom features to the comparison dashboard:

1. Go to **Admin > Configuration > AI > Drupal Native AI > Model Feature Registry**
2. Click **Add Model Feature**
3. Fill in the feature details:
   - **Feature Name**: Human-readable name
   - **Machine Name**: Unique identifier (lowercase, underscores)
   - **Category**: Which category this feature belongs to
   - **Feature Key**: Key used in model data
   - **Description**: Explanation of the feature
   - **Feature Type**: Boolean, Number, String, or Select
   - **Unit**: For numeric features, the unit of measurement
   - **Higher is Better**: For numeric features, whether higher values are better
   - **Display Weight**: Controls the order of features
   - **Feature Importance**: How important this feature is (1-10)

## Technical Details

The feature comparison dashboard uses:

- A configuration entity (`model_feature_registry`) to store feature definitions
- Dynamic value analysis to determine better/worse values
- Interactive JavaScript for filtering and highlighting
- Responsive design that works well on all screen sizes

<!-- TODO-DOCS-01: Improve technical documentation
Priority: medium
Estimated time: 4 hours
Tasks:
- Add comprehensive installation instructions
- Create troubleshooting section with common issues
- Document performance considerations and caching strategy
- Add documentation for extending the feature comparison system
- Enhance API examples with more context and explanation
- Add code samples for common customization scenarios
See: FEATURE_BENCHMARK_AUDIT_REPORT.md
-->

## Integration with Other Modules

The feature comparison dashboard can be extended by other modules:

- Add custom feature categories
- Register additional features
- Add custom value analysis logic
- Extend the export functionality

## API Usage

You can programmatically access the feature comparison data:

```php
// Get the feature comparison service
$comparison_service = \Drupal::service('drupal_native_ai.model_comparison');

// Get feature definitions
$features = \Drupal::entityTypeManager()
  ->getStorage('model_feature_registry')
  ->loadMultiple();

// Get model data
$models = $comparison_service->getModels();

// Export comparison data
$export_data = [
  'models' => $models,
  'features' => $features,
  // Additional data...
];
```
