---
id: modules-development-native_ai-INSTALLATION
---
# Installation Guide for Drupal Native AI

This document provides detailed instructions for installing and configuring the Drupal Native AI module.

## Requirements

Before installing this module, ensure your system meets the following requirements:

- PHP 8.1 or higher
- Drupal 10.1 or 11.0
- Required Drupal core modules:
  - System
  - Field
  - Entity
  - Typed Data
  - Cache
  - State
  - Database
  - Language
  - Migrate
  - Migrate Plus
  - Options
  - Path
- Optional modules (recommended):
  - Key (for secure API key storage)
  - Queue UI (for monitoring AI processing queues)
  - Components (for UI integration)

## Installation Methods

### Using Composer (Recommended)

1. Add the Drupal package repository to your project's `composer.json` if it's not already there:

   ```json
   "repositories": [
       {
           "type": "composer",
           "url": "https://packages.drupal.org/8"
       }
   ]
   ```

2. Require the module using Composer:

   ```bash
   composer require drupal/drupal_native_ai
   ```

3. Enable the module using Drush:

   ```bash
   drush en drupal_native_ai
   ```

   Or enable it through the Drupal admin interface at `/admin/modules`.

### Manual Installation

1. Download the module from [drupal.org/project/drupal_native_ai](https://www.drupal.org/project/drupal_native_ai)
2. Extract the contents to your Drupal site's `modules/contrib` directory
3. Enable the module through the Drupal admin interface at `/admin/modules`

## Post-Installation Configuration

After installing the module, you'll need to configure it for your specific use case:

1. Navigate to Administration > Configuration > AI > Drupal Native AI Settings (`/admin/config/ai/drupal_native_ai`)
2. Configure general settings:
   - Default AI provider
   - API credentials (via Key module if installed)
   - Streaming settings
   - Metrics collection settings
3. Configure model settings:
   - Register AI models
   - Configure model parameters
   - Set model visibility and access
4. Save configuration

## Advanced Server Configuration

For production environments, consider these additional configurations:

### PHP Configuration

Recommended PHP settings for optimal performance:

```ini
memory_limit = 256M
max_execution_time = 120
upload_max_filesize = 20M
post_max_size = 20M
```

### Web Server Configuration

#### Apache

Example Apache configuration for handling streaming responses:

```apache
<VirtualHost *:80>
    # ... other configuration ...
    
    # Enable HTTP/1.1 streaming
    SetEnv force-response-1.0 0
    
    # Disable output buffering
    SetEnv no-gzip 1
    SetEnv dont-vary 1
    
    # Increase timeout for AI operations
    Timeout 300
</VirtualHost>
```

#### Nginx

Example Nginx configuration for handling streaming responses:

```nginx
server {
    # ... other configuration ...
    
    # Increase timeouts for AI operations
    proxy_read_timeout 300s;
    proxy_send_timeout 300s;
    
    # Disable buffering for streaming responses
    proxy_buffering off;
    
    # ... other configuration ...
}
```

## Troubleshooting

If you encounter issues during installation or configuration, check the following:

### Common Issues

1. **Module Dependencies**: Ensure all required modules are installed and enabled.
2. **PHP Version**: Verify that your PHP version meets the requirements.
3. **Memory Limits**: Check if PHP memory limit is sufficient.
4. **Permissions**: Ensure the web server has write permissions to the necessary directories.
5. **Cache Issues**: Clear Drupal cache after installation and configuration changes.

### Error Logs

Check the following logs for error messages:

- Drupal watchdog logs: `/admin/reports/dblog`
- PHP error logs: Check your web server's error log configuration
- JavaScript console errors: Check your browser's developer tools

### Getting Help

If you're still having issues, you can:

1. Check the [module issue queue](https://www.drupal.org/project/issues/drupal_native_ai) for similar issues
2. Create a new issue with detailed information about your problem
3. Reach out to the community through Drupal Slack or forums

## Next Steps

After installation and configuration, check out these resources to get started:

- [User Guide](USER_GUIDE): Learn how to use the module's features
- [Developer Guide](DEVELOPER_GUIDE): Learn how to extend and customize the module
- [API Reference](API_REFERENCE): Reference documentation for developers
- [Examples](../examples/): Example code for common use cases
