---
id: modules-development-native_ai-NAMING_CONVENTION_CHANGES
---
# Naming Convention Changes

This document tracks the changes made to class, file, and service names to follow Drupal coding standards and best practices.

## Superlative Term Removal

As part of our commitment to maintaining clean, professional code, we've removed superlative terms like "enhanced", "advanced", and "optimized" from our codebase. These terms are subjective and don't provide clear information about the functionality.

### File and Class Renames

The following files and classes have been renamed:

| Original Name | New Name | Description |
|---------------|----------|-------------|
| AgentFormEnhanced | AgentFormUI | UI-focused agent configuration form |
| SettingsFormEnhanced | SettingsFormUI | UI-focused settings form |
| EnhancedNativeAiJsProvider | UINativeAiJsProvider | UI-focused provider implementation |
| EnhancedNodeJsBridge | UINodeJsBridge | UI-focused Node.js bridge |
| AdvancedNodeJsBridge | StandardNodeJsBridge | Standard Node.js bridge with extended features |

### CSS and JavaScript Files

CSS and JavaScript files have been renamed to match their corresponding PHP classes:

| Original Name | New Name | Description |
|---------------|----------|-------------|
| agent-form-enhanced.css | agent-form-ui.css | Styles for the agent form UI |
| agent-form-enhanced.js | agent-form-ui.js | JavaScript for the agent form UI |
| settings-form-enhanced.css | settings-form-ui.css | Styles for the settings form UI |
| settings-form-enhanced.js | settings-form-ui.js | JavaScript for the settings form UI |

### Service Definitions

Service definitions have been updated to use the new class names:

| Original Service | New Service | Description |
|------------------|-------------|-------------|
| drupal_native_ai_nativeaijs.enhanced_provider | drupal_native_ai_nativeaijs.ui_provider | UI-focused provider service |
| drupal_native_ai_nativeaijs.enhanced_nodejs_bridge | drupal_native_ai_nativeaijs.ui_nodejs_bridge | UI-focused Node.js bridge service |
| drupal_native_ai_nativeaijs.advanced_nodejs_bridge | drupal_native_ai_nativeaijs.standard_nodejs_bridge | Standard Node.js bridge service |

### Documentation Files

Documentation files have been renamed to match the new class names:

| Original Name | New Name | Description |
|---------------|----------|-------------|
| ENHANCED_SETTINGS_FORM.md | SETTINGS_FORM_UI.md | Documentation for the settings form UI |

## Best Practices

All new code should follow these naming conventions:

1. Avoid superlative terms in class, method, file, and service names
2. Use descriptive names that indicate the purpose or function, not subjective qualities
3. Follow Drupal coding standards for naming conventions
4. Prefer specific, functional names over vague, promotional terms

## Future Work

We will continue to identify and rename elements that use superlative terms. Any new code should follow these updated naming conventions.
