---
id: modules-development-native_ai-PROVIDER_ENHANCEMENTS
---
# Provider Auto-Detection Enhancements

## Overview

We've implemented a comprehensive provider auto-detection and configuration system that reinforces Drupal Native AI as the default provider while making commercial providers completely optional. These enhancements make it easier for users to configure their AI providers while ensuring that native capabilities are used whenever possible.

## Key Features Implemented

### 1. Provider Detection Service

The core of the system is the `ProviderDetectionService` which:

- Automatically scans for available AI providers
- Determines provider status (configured, available, missing dependency)
- Groups providers by type (native, commercial, local, framework)
- Provides recommendations based on setup type
- Maps operations to appropriate providers based on capabilities

### 2. Command-Line Tools

- **Drush Commands**: Added commands for provider detection and configuration
  - `drupal_native_ai:detect-providers`: Scans and displays available providers
  - `drupal_native_ai:configure-providers`: Configures providers with specified setup type

- **Configuration Script**: Created a shell script (`configure-providers.sh`) for easy command-line configuration with options for:
  - Setup type (recommended, hybrid, minimal)
  - Provider selection
  - Force native provider setting

### 3. API Improvements

- **Provider Configuration**: Enhanced the API for configuring providers
  - Auto-detection of appropriate fallbacks
  - Capability-based provider selection
  - Prioritization based on provider type

- **Operation Mapping**: Implemented intelligent mapping of operations to providers
  - Required capabilities for each operation
  - Provider capability checks
  - Optimal provider selection

### 4. Documentation

- Created comprehensive documentation:
  - `PROVIDER_AUTO_DETECTION.md`: Overview of the auto-detection system
  - `PROVIDER_HOOKS.md`: Integration points for other modules
  - Examples in `examples/provider_configuration.php`
  - Updated README.md with command-line usage instructions

## Implementation Details

### Provider Detection

The system detects providers from various sources:

1. **Drupal Native AI Provider**: Always available as the default
2. **LLM Module Providers**: OpenAI, Anthropic
3. **Module-Specific Providers**: Hugging Face, Ollama, LangChain
4. **Custom Providers**: Via provider hooks and services

Each provider is categorized by type and assigned a priority, with native providers having the highest priority.

### Setup Types

Three setup types are supported:

1. **Recommended**: Native provider as primary with commercial fallbacks for specialized operations
2. **Hybrid**: Mix of native and commercial providers based on capabilities
3. **Minimal**: Only native provider without external providers

### Operation Capabilities

Operations are mapped to required capabilities:

- Text generation operations (generate, chat)
- Image operations (generate_image, classify_image)
- Speech operations (text_to_speech, speech_to_text)
- Embedding operations (generate_embeddings)
- Translation operations (translate_text)
- Content operations (moderate_content)
- AI Swarm operations (analyze_pattern_emergence, etc.)
- LangChain operations (execute_prompt, orchestrate_chain, etc.)
- Field ECA Bridge operations (process_field_value, etc.)

The system selects the best provider for each operation based on these required capabilities.

## Integration with Existing System

The new provider auto-detection system integrates seamlessly with:

- **Setup Wizard**: Enhanced with auto-detection and provider selection
- **Provider Status Block**: Displays detected providers with status indicators
- **Provider Configuration Forms**: Still accessible for manual configuration
- **Provider Manager**: Automatic registration of detected providers

## Benefits

1. **Simplicity**: Users can set up their AI providers with minimal effort
2. **Flexibility**: Multiple setup types for different needs
3. **Performance**: Native provider used whenever possible for better performance
4. **Cost Optimization**: Commercial providers only used when necessary
5. **Extensibility**: Easy integration points for new providers

## Next Steps

Potential future enhancements:

1. **Automated Testing**: Create test coverage for the provider detection system
2. **UI Improvements**: Enhance the provider status block with more details
3. **Telemetry**: Add usage tracking to optimize provider selection
4. **Performance Optimization**: Fine-tune provider selection based on performance metrics
5. **Auto-Healing**: Implement automatic fallback if a provider fails
