---
id: modules-development-native_ai-SUPERLATIVE_TERM_REMOVAL
---
# Superlative Term Removal

This document describes the process and tools for removing superlative terms from code.

## Completed Work

1. Renamed `AdvancedNodeJsBridge.php` to `StandardNodeJsBridge.php` with equivalent functionality
2. Updated the Drupal service definitions to include the new class and maintain backward compatibility
3. Created a documentation file to track naming convention changes (`NAMING_CONVENTION_CHANGES.md`)

## New Tools Created

### 1. Shell Script

Created a shell script to automate the removal of superlative terms:

- Location: `./bfcli/scripts/remove-superlatives.sh`
- Purpose: Renames files, updates class names, and modifies service definitions
- Features:
  - Creates backups before making changes
  - Adds backward compatibility aliases
  - Logs all changes
  - Supports dry run mode

### 2. BFCLI Command

Created a new BFCLI command to make the script easily accessible:

- Command: `bfcli remove-superlatives`
- Location: `./bfcli/src/commands/maintenance/RemoveSuperlativesCommand.ts`
- Options:
  - `--directory <path>`: Target directory to process
  - `--no-backup`: Skip creating backups
  - `--dry-run`: Show what would change without making changes
  - `--verbose`: Show detailed output

## Using the New Command

To remove superlative terms from a codebase:

```bash
# Basic usage (processes current directory)
bfcli remove-superlatives

# Specify a target directory
bfcli remove-superlatives --directory ./src

# Dry run (shows what would change without making actual changes)
bfcli remove-superlatives --dry-run
```

## Default Replacement Mapping

| Superlative Term | Replacement |
|------------------|-------------|
| Enhanced | UI |
| enhanced | ui |
| Advanced | Standard |
| advanced | standard |
| Optimized | Efficient |
| optimized | efficient |
| Revolutionary | Core |
| revolutionary | core |
| Superior | Professional |
| superior | professional |
| Ultimate | Complete |
| ultimate | complete |
| Premium | Pro |
| premium | pro |

## Backward Compatibility

The tools automatically add backward compatibility mechanisms:

1. PHP class aliases:
```php
class_alias(UINodeJsBridge::class, 'Drupal\example\Bridge\EnhancedNodeJsBridge');
```

2. Drupal service aliases:
```yaml
# Backward compatibility alias for enhanced_nodejs_bridge
example.enhanced_nodejs_bridge:
  alias: example.ui_nodejs_bridge
  class: Drupal\example\Bridge\UINodeJsBridge
```

## Best Practices

When removing superlative terms:

1. Start with a clean, committed codebase
2. Run with `--dry-run` first to see what would change
3. Use a consistent replacement mapping across all projects
4. Maintain backward compatibility through aliases
5. Update documentation to reflect the new naming conventions
6. Test thoroughly after making changes
