---
id: platform-archived-MODULE_FIX_PRIORITY
---
# Module Fix Priority List

## 🎯 Priority Order for Fixing Modules

### ✅ Phase 1: Core Working Modules (Already Working)
These are your foundation - keep them stable while fixing others.

1. **api_normalization** ✅ DONE
   - Status: Enabled and working
   - Native Drupal integration complete
   - Use as template for other modules

2. **llm** ✅ DONE (Basic functionality)
   - Status: Enabled and working
   - Controllers fixed
   - Ready for submodule integration

---

### 🔧 Phase 2: High-Value Modules to Fix Next (Week 1)

3. **secure_drupal** ✅ DONE
   - Status: Enabled (with fixes)
   - Fixed: YAML syntax errors in ECA rules
   - Fixed: Service collector issues
   - Fixed: Queue worker configuration
   - Note: Some proxy classes need generation
   
4. **llm_ai** ✅ DONE
   - Status: Enabled
   - Fixed: Removed custom_field dependencies
   - Fixed: Disabled problematic ECA models
   - Note: Some proxy classes need generation

5. **llm_ui** 🔴 IN PROGRESS
   - Status: Trying to enable
   - Issue: LazyPluginCollection class loading error
   - Value: User interface for LLM features
   - Next: Investigate class loading issue

---

### 🔨 Phase 3: Integration Modules (Week 2)

6. **llm_eca** 🟡 MEDIUM PRIORITY
   - Status: Disabled
   - Value: Workflow automation with ECA
   - Dependencies: ECA module (contrib)
   - Fix: Verify ECA is installed first

7. **field_eca_bridge** 🟡 MEDIUM PRIORITY
   - Status: Available but needs custom_field
   - Value: Bridges fields with workflows
   - Fix: Either install custom_field OR refactor to use standard fields

8. **llm_openapi** 🟡 MEDIUM PRIORITY
   - Status: Disabled
   - Version: 1.0.0
   - Value: API documentation
   - Fix: Should work once base modules are stable

---

### 🛠️ Phase 4: Feature Modules (Week 3)

9. **llm_vector** 🟡 MEDIUM PRIORITY
   - Status: Disabled
   - Version: 1.0.0
   - Value: Vector search capabilities
   - Fix: Requires vector database setup

10. **llm_embeddings** 🟡 MEDIUM PRIORITY
    - Status: Disabled
    - Value: Text embeddings for AI
    - Fix: Depends on llm_vector

11. **llm_search** 🟡 MEDIUM PRIORITY
    - Status: Disabled
    - Value: AI-powered search
    - Dependencies: search_api (contrib)

---

### 🔄 Phase 5: Consolidation Candidates (Week 4)

12. **langchain** 🟠 LOW PRIORITY
    - Status: Available but redundant
    - Action: Merge useful features into llm
    - Keep: Deprecation notices for smooth transition

13. **ai_swarm_intelligence** 🟠 LOW PRIORITY
    - Status: Complex module with property conflicts
    - Action: Extract useful agent features to llm_orchestration
    - Fix: Major refactoring needed

14. **drupal_native_ai** 🟠 LOW PRIORITY
    - Status: Not enabled, 114 PHP files
    - Action: Cherry-pick useful features to llm
    - Keep: As reference/documentation

---

### ❌ Phase 6: Deprecate/Archive (Future)

15. **blockchain_manager** 🔴 ARCHIVE
    - Status: No .module file
    - Action: Move to __DELETE_LATER

16. **marketplace_integration** 🔴 ARCHIVE
    - Status: Incomplete
    - Action: Move to __DELETE_LATER

17. **experience_builder_converter** 🔴 ARCHIVE
    - Status: Unclear purpose
    - Action: Move to __DELETE_LATER

18. **drupal_migration_plus** 🔴 ARCHIVE
    - Status: Conflicts with contrib
    - Action: Move to __DELETE_LATER

---

## 📋 Quick Fix Checklist

### For Each Module:

1. **Controller Property Conflicts**
   ```php
   // BAD: Typed property conflicts with parent
   protected EntityTypeManagerInterface $entityTypeManager;
   
   // GOOD: No type declaration
   protected $entityTypeManager;
   ```

2. **Service Definition Issues**
   ```yaml
   # Remove broken service collectors
   # Check all service dependencies exist
   # Use proper dependency injection
   ```

3. **Missing Dependencies**
   ```bash
   # Check if contrib modules exist
   composer require drupal/module_name
   
   # Update .info.yml dependencies
   ```

4. **Routing Issues**
   ```yaml
   # Ensure controller classes exist
   # Fix controller method references
   # Update permissions
   ```

## 🚀 Implementation Order

### Week 1: Stabilize Core
1. Complete llm controller fixes ✅ (in progress)
2. Fix secure_drupal property conflicts
3. Enable llm_ai and llm_ui
4. Test basic functionality

### Week 2: Add Integration
5. Enable llm_eca for workflows
6. Fix field_eca_bridge dependencies
7. Enable llm_openapi for documentation
8. Test integration features

### Week 3: Enhance Features
9. Setup llm_vector with database
10. Enable llm_embeddings
11. Configure llm_search with search_api
12. Test advanced features

### Week 4: Consolidate
13. Merge langchain features to llm
14. Extract ai_swarm useful code
15. Archive deprecated modules
16. Final testing and documentation

## 📊 Success Metrics

- [ ] No fatal errors when enabling modules
- [ ] All property conflicts resolved
- [ ] Service definitions validated
- [ ] Dependencies documented
- [ ] Basic functionality tested
- [ ] Integration points working
- [ ] Documentation updated

## 🎯 Quick Wins First

Start with these easy fixes:
1. **Controller property conflicts** - Just remove type declarations
2. **Broken routes** - Comment out or fix controller references
3. **Service collectors** - Comment out broken ones
4. **Missing classes** - Create stub classes or comment out

Remember: Get modules working first, optimize later!
