---
id: projects
---
# Project Documentation

This section provides links to documentation for all projects in the Bluefly LLM Platform ecosystem.

## Architecture Overview

The platform consists of 10 integrated projects:

```mermaid
graph TB
    subgraph "Core Services"
        BFAPI[BFAPI - API Gateway]
        BFLLM[BFLLM - LLM Services]
        BFMCP[BFMCP - Model Control]
    end
    
    subgraph "Developer Tools"
        BFCLI[BFCLI - CLI Tool]
        BFCI[BFCI Components]
    end
    
    subgraph "Frontend & SDKs"
        BFUI[BFUI - React Components]
        BFCLIENT[BFAPI Client SDK]
        BFRFP[BFRFP - Content Gen]
    end
    
    subgraph "Integration Layer"
        DRUPAL[Drupal Modules]
        UNIFIED[Unified Compliance]
    end
    
    BFCLI --> BFAPI
    BFAPI --> BFLLM
    BFAPI --> BFMCP
    BFUI --> BFCLIENT
    BFCLIENT --> BFAPI
    DRUPAL --> BFAPI
    BFRFP --> BFLLM
```

## Projects by Category


### Security

- [Unified Compliance Framework](./unified-compliance) - Enterprise-grade security, compliance, and code quality framework for the Bluefly ecosystem
\n
### Core Services

- [BFAPI - API Gateway & Normalization](./bfapi) - API gateway with request normalization, routing, and security
\n
### Developer Tools

- [BFCLI - Developer CLI & Automation](./bfcli) - Comprehensive CLI for platform management, CI/CD operations, and development workflows
\n
### AI Services

- [BFLLM - LLM Training & Inference](./bfllm) - LLM training, inference, model registry with distributed computing support\n- [BFRFP - AI Content Generation](./bfrfp) - AI-powered content generation and RFP automation service
\n
### Protocol Services

- [BFMCP - MCP Protocol Server](./bfmcp) - Model Context Protocol server for tool orchestration and agent workflows
\n
### Frontend

- [BFUI - React Component Library](./bfui) - React component library for AI platform interfaces and Experience Builder integration
\n
### Client Libraries

- [BFAPI Client - TypeScript SDK](./bfapiclient) - Auto-generated TypeScript SDK for API integration
\n
### DevOps

- [BFCI Components - GitLab CI/CD](./bfcicomponents) - GitLab CI/CD components with 195 test cases and 100% automation coverage
\n
### Drupal Integration

- [Drupal AI Modules - Control Plane](./_DrupalModules) - 200+ Drupal modules + 9 custom AI modules for platform orchestration


## Quick Links

- [Platform Architecture](/architecture/)
- [Getting Started Guide](/getting-started/)
- [API Documentation](/api/)
- [Development Standards](/development/)
- [Deployment Guide](/deployment/)
